==> crm-commom-vo-1.2.8.3.release.jar: com/biz/crm/common/param/RedisParam.java <==
package com.biz.crm.common.param;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.base.param
 * @Description: TODO
 * @date 2020/8/28 下午1:08
 */
public class RedisParam {
    public static final int TIME1 = 1;
    public static final int TIME3 = 3;
    public static final int TIME5 = 5;
    public static final int TIME10 = 10;
    public static final int TIME30 = 30;
    public static final int TIME365 = 365;
    public static final int YEAR5 = 365*5;
    public static final int MONTH1 = 30*24*60*60;
    public static final int YEAR2 = 60*60*24*365*2;
    //当前用户登录，token与用户关系前缀
    public static final String LOGIN_USER_TOKEN_PREFIX = "LOGIN_USER_TOKEN_";

    /**
     * 字典类型key 前缀
     */
    public static final String DICT_TYPE = "DICT_TYPE_:";
    public static final String DICT_DATA = "DICT_DATA_:";
    //数据字典类型编码
    public static final String DICT_TYPE_LOCK = "DICT_TYPE_LOCK_1231:";
    public static final String DICT_TYPE_GROUP = "DICT_TYPE_GROUP_1231:";

    //企业组织缓存
    public static final String MDM_ORG_LOCK_HASH = "MDM_ORG_LOCK_HASH_0112:";
    public static final String MDM_ORG_PARENT_HASH = "MDM_ORG_PARENT_HASH_0112:";
    public static final String MDM_ORG_CHILDREN_HASH = "MDM_ORG_CHILDREN_HASH_0112:";
    public static final String MDM_ORG_SELF_HASH = "MDM_ORG_SELF_HASH_0112:";

    //流程角色缓存
    public static final String MDM_BPM_ROLE_LOCK_HASH = "MDM_BPMROLE_LOCK_HASH_0112:";
    public static final String MDM_BPM_ROLE_SELF_HASH = "MDM_BPMROLE_SELF_HASH_0112:";

    //职位缓存
    public static final String MDM_POSITION_LOCK_HASH = "MDM_POSITION_LOCK_HASH_0112:";
    public static final String MDM_POSITION_PARENT_HASH = "MDM_POSITION_PARENT_HASH_0112:";
    public static final String MDM_POSITION_CHILDREN_HASH = "MDM_POSITION_CHILDREN_HASH_0112:";
    public static final String MDM_POSITION_SELF_HASH = "MDM_POSITION_SELF_HASH_0112:";

    //产品层级缓存
    public static final String MDM_PRODUCT_LEVEL_LOCK_HASH = "MDM_PRODUCT_LEVEL_LOCK_HASH_0112:";
    public static final String MDM_PRODUCT_LEVEL_PARENT_HASH = "MDM_PRODUCT_LEVEL_PARENT_HASH_0112:";
    public static final String MDM_PRODUCT_LEVEL_CHILDREN_HASH = "MDM_PRODUCT_LEVEL_CHILDREN_HASH_0112:";
    public static final String MDM_PRODUCT_LEVEL_SELF_HASH = "MDM_PRODUCT_LEVEL_SELF_HASH_0112:";

    /***全局参数前缀*/
    public static final String PARAMETER = "PARAMETER_:";
    /***全局参数加锁前缀*/
    public static final String PARAMETER_LOCK = "PARAMETER_LOCK_:";
    //错误一次编码
    public static final String ERROE_CODE="ERROE_CODE_";
    //错误编码前缀
    public static final String ERROE_MSG="ERROE_MSG_:";

    public static final String TOKEN = "token:";

    /**
     * 登录密码错误次数
     */
    public static final String LOGIN_ERROR_FREQUENCY = "login_error_frequency:";

    /**
     * 登录错误锁定时长
     */
    public static final String LOGIN_LOCK_TIME = "login_lock_time:";

    /**
     * 页面配置
     */
    public static final String TABLE_CONFIG = "table_config:";
}

==> crm-commom-vo-1.3.0.0.release.jar: com/biz/crm/common/param/RedisParam.java <==
package com.biz.crm.common.param;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.base.param
 * @Description: TODO
 * @date 2020/8/28 下午1:08
 */
public class RedisParam {
    public static final int TIME1 = 1;
    public static final int TIME3 = 3;
    public static final int TIME5 = 5;
    public static final int TIME10 = 10;
    public static final int TIME30 = 30;
    public static final int TIME365 = 365;
    public static final int YEAR5 = 365*5;
    public static final int MONTH1 = 30*24*60*60;
    public static final int MONTH3 = 30*24*60*60*2;
    public static final int YEAR2 = 60*60*24*365*2;
    //当前用户登录，token与用户关系前缀
    public static final String LOGIN_USER_TOKEN_PREFIX = "LOGIN_USER_TOKEN_";

    /**
     * 字典类型key 前缀
     */
    public static final String DICT_TYPE = "DICT_TYPE_:";
    public static final String DICT_DATA = "DICT_DATA_:";
    //数据字典类型编码
    public static final String DICT_TYPE_LOCK = "DICT_TYPE_LOCK_1231:";
    public static final String DICT_TYPE_GROUP = "DICT_TYPE_GROUP_1231:";

    //企业组织缓存
    public static final String MDM_ORG_LOCK_HASH = "MDM_ORG_LOCK_HASH_0112:";
    public static final String MDM_ORG_PARENT_HASH = "MDM_ORG_PARENT_HASH_0112:";
    public static final String MDM_ORG_CHILDREN_HASH = "MDM_ORG_CHILDREN_HASH_0112:";
    public static final String MDM_ORG_SELF_HASH = "MDM_ORG_SELF_HASH_0112:";

    //流程角色缓存
    public static final String MDM_BPM_ROLE_LOCK_HASH = "MDM_BPM_ROLE_LOCK_HASH_0112:";
    public static final String MDM_BPM_ROLE_SELF_HASH = "MDM_BPM_ROLE_SELF_HASH_0112:";

    //职位缓存
    public static final String MDM_POSITION_LOCK_HASH = "MDM_POSITION_LOCK_HASH_0112:";
    public static final String MDM_POSITION_PARENT_HASH = "MDM_POSITION_PARENT_HASH_0112:";
    public static final String MDM_POSITION_CHILDREN_HASH = "MDM_POSITION_CHILDREN_HASH_0112:";
    public static final String MDM_POSITION_SELF_HASH = "MDM_POSITION_SELF_HASH_0112:";

    //产品层级缓存
    public static final String MDM_PRODUCT_LEVEL_LOCK_HASH = "MDM_PRODUCT_LEVEL_LOCK_HASH_0112:";
    public static final String MDM_PRODUCT_LEVEL_PARENT_HASH = "MDM_PRODUCT_LEVEL_PARENT_HASH_0112:";
    public static final String MDM_PRODUCT_LEVEL_CHILDREN_HASH = "MDM_PRODUCT_LEVEL_CHILDREN_HASH_0112:";
    public static final String MDM_PRODUCT_LEVEL_SELF_HASH = "MDM_PRODUCT_LEVEL_SELF_HASH_0112:";

    //客户组织缓存
    public static final String MDM_CUSTOMER_ORG_LOCK_HASH = "MDM_CUSTOMER_ORG_LOCK_HASH_0201:";
    public static final String MDM_CUSTOMER_ORG_PARENT_HASH = "MDM_CUSTOMER_ORG_PARENT_HASH_0201:";
    public static final String MDM_CUSTOMER_ORG_CHILDREN_HASH = "MDM_CUSTOMER_ORG_CHILDREN_HASH_0201:";
    public static final String MDM_CUSTOMER_ORG_SELF_HASH = "MDM_CUSTOMER_ORG_SELF_HASH_0201:";

    /***全局参数前缀*/
    public static final String PARAMETER = "PARAMETER_:";
    /***全局参数加锁前缀*/
    public static final String PARAMETER_LOCK = "PARAMETER_LOCK_:";
    //错误一次编码
    public static final String ERROE_CODE="ERROE_CODE_";
    //错误编码前缀
    public static final String ERROE_MSG="ERROE_MSG_:";

    public static final String TOKEN = "token:";

    /**
     * 登录密码错误次数
     */
    public static final String LOGIN_ERROR_FREQUENCY = "login_error_frequency:";

    /**
     * 登录错误锁定时长
     */
    public static final String LOGIN_LOCK_TIME = "login_lock_time:";

    /**
     * 页面配置
     */
    public static final String TABLE_CONFIG = "table_config:";
}
